﻿using System.IO;
using System.Windows.Forms;
using System.Text;
using Eplan.EplApi.ApplicationFramework;
using Eplan.EplApi.Base;
using Eplan.EplApi.Scripting;


public class Script
{
    public float ReadTextFile(string strFile)
    {
        string strContent = "";
        float weightBM = 0;
        int countInvalidLines = 0;

        StreamReader srTextfile = new StreamReader(strFile, Encoding.Unicode);

        while (!srTextfile.EndOfStream)
        {
            strContent = srTextfile.ReadLine();

            string[] values = strContent.Split(';');
            if (values.Length == 3)
            {
                if (values[0] != "" && values[1] != "" && values[2] != "")
                {
                    float count = float.Parse(values[1]);
                    float singleWeight = float.Parse(values[2]);
                    weightBM += count * singleWeight;
                }
                else
                {
                    countInvalidLines++;
                }
            }
        }


        srTextfile.Close();

        if (countInvalidLines > 0)
        {
            MessageBox.Show(countInvalidLines.ToString(), "Anzahl unvollständiger Artikel");
        }
        return weightBM;
    }


    [Start]

    public void AutoTreat()
    {
        String strProjectName = PathMap.SubstitutePath("$(P)");
        String strSettingsFolder = PathMap.SubstitutePath("$(MD_SCRIPTS)" + @"\Gewichtsermittlung");
        Int32 nImportSettings = 0;
        Int32 nCompleteProject = 1;
        String strSelectionFilter = PathMap.SubstitutePath("$(MD_SCRIPTS)" + @"\Gewichtsermittlung");

        string strBM_Gewichte = PathMap.SubstitutePath("$(MD_DOCUMENTS)" + @"\Sammelordner P8\Gewichte\$(PROJECTNAME)_BM.txt");
        string strSchienen_Gewichte = PathMap.SubstitutePath("$(MD_DOCUMENTS)" + @"\Sammelordner P8\Gewichte\$(PROJECTNAME)_Schienen.txt");
        string strLeitungen_Gewichte = PathMap.SubstitutePath("$(MD_DOCUMENTS)" + @"\Sammelordner P8\Gewichte\$(PROJECTNAME)_Leitungen.txt");

        Progress progress = new Progress("SimpleProgress");
        progress.SetAllowCancel(true);
        bool bResult = true;
        int nActionsPercent = 100;
        if (nCompleteProject == 0 && nImportSettings == 1)
        {
            progress.BeginPart(10, "ReadSelectionSettings");
            nActionsPercent -= 10;
            Eplan.EplApi.Base.Settings xmlSettings = new Eplan.EplApi.Base.Settings();
            xmlSettings.ReadSettings(strSettingsFolder + @"\Selection.xml");
            progress.EndPart();
        }
        progress.BeginPart(nActionsPercent, "");
        nActionsPercent = 100;
        if (!progress.Canceled())
        {
            if (nImportSettings == 1)
            {
                progress.BeginPart(25 / 3, "ReadSettings");
                nActionsPercent -= 25;
                Eplan.EplApi.Base.Settings xmlSettings = new Eplan.EplApi.Base.Settings();
                xmlSettings.ReadSettings(strSettingsFolder + @"\Settings1.xml");
                progress.EndPart();


            }
        }
        if (!progress.Canceled())
        {
            progress.BeginPart(nActionsPercent / 3, "Gewichte BM");
            ActionCallingContext context1 = new ActionCallingContext();
            context1.AddParameter("configscheme", "Gewichte_txt_BM");
            context1.AddParameter("filterscheme", "");
            context1.AddParameter("sortscheme", "");
            context1.AddParameter("language", "de_DE");
            context1.AddParameter("destinationfile", strBM_Gewichte);
            context1.AddParameter("recrepeat", "1");
            context1.AddParameter("taskrepeat", "1");
            context1.AddParameter("showoutput", "0");
            context1.AddParameter("ProjectName", strProjectName);

            if (nCompleteProject == 1)
            {
                context1.AddParameter("type", "PROJECT");
            }
            else
            {
                context1.AddParameter("type", "PAGES");
                context1.AddParameter("PAGEFILTERNAME", strSelectionFilter);
            }
            bResult &= new CommandLineInterpreter().Execute("label", context1);
            progress.EndPart();
        }
        nActionsPercent = 100;
        if (!progress.Canceled())
        {
            if (nImportSettings == 1)
            {
                progress.BeginPart(25 / 3, "ReadSettings");
                nActionsPercent -= 25;
                Eplan.EplApi.Base.Settings xmlSettings = new Eplan.EplApi.Base.Settings();
                xmlSettings.ReadSettings(strSettingsFolder + @"\Settings2.xml");
                progress.EndPart();
            }
        }
        if (!progress.Canceled())
        {
            progress.BeginPart(nActionsPercent / 3, "Gewichte Schienen");
            ActionCallingContext context2 = new ActionCallingContext();
            context2.AddParameter("configscheme", "Gewichte_txt_Schienen");
            context2.AddParameter("filterscheme", "");
            context2.AddParameter("sortscheme", "");
            context2.AddParameter("language", "de_DE");
            context2.AddParameter("destinationfile", strSchienen_Gewichte);
            context2.AddParameter("recrepeat", "1");
            context2.AddParameter("taskrepeat", "1");
            context2.AddParameter("showoutput", "0");
            context2.AddParameter("ProjectName", strProjectName);
            if (nCompleteProject == 1)
            {
                context2.AddParameter("type", "PROJECT");
            }
            else
            {
                context2.AddParameter("type", "PAGES");
                context2.AddParameter("PAGEFILTERNAME", strSelectionFilter);
            }
            bResult &= new CommandLineInterpreter().Execute("label", context2);
            progress.EndPart();
        }
        nActionsPercent = 100;
        if (!progress.Canceled())
        {
            if (nImportSettings == 1)
            {
                progress.BeginPart(25 / 3, "ReadSettings");
                nActionsPercent -= 25;
                Eplan.EplApi.Base.Settings xmlSettings = new Eplan.EplApi.Base.Settings();
                xmlSettings.ReadSettings(strSettingsFolder + @"\Settings3.xml");
                progress.EndPart();
            }
        }
        if (!progress.Canceled())
        {
            progress.BeginPart(nActionsPercent / 3, "Gewichte Leitungen");
            ActionCallingContext context3 = new ActionCallingContext();
            context3.AddParameter("configscheme", "Gewichte_txt_Leitungen");
            context3.AddParameter("filterscheme", "");
            context3.AddParameter("sortscheme", "");
            context3.AddParameter("language", "de_DE");
            context3.AddParameter("destinationfile", strLeitungen_Gewichte);
            context3.AddParameter("recrepeat", "1");
            context3.AddParameter("taskrepeat", "1");
            context3.AddParameter("showoutput", "0");
            context3.AddParameter("ProjectName", strProjectName);
            if (nCompleteProject == 1)
            {
                context3.AddParameter("type", "PROJECT");
            }
            else
            {
                context3.AddParameter("type", "PAGES");
                context3.AddParameter("PAGEFILTERNAME", strSelectionFilter);
            }
            bResult &= new CommandLineInterpreter().Execute("label", context3);
            progress.EndPart();
        }
        progress.EndPart(true);


        // Text-Dateien öffnen, Zeilen lesen & ermitteln der Teilgewichte

        float bm1 = ReadTextFile(strBM_Gewichte);
        float bm2 = ReadTextFile(strSchienen_Gewichte);
        float bm3 = ReadTextFile(strLeitungen_Gewichte) / 1000;

        // addieren der Teilgewichte

        float totalWeight = bm1 + bm2 + bm3;
        MessageBox.Show(totalWeight.ToString(), "Gesamtgewicht");

        // speichern des Gesamtgewichtes als Projekteigenschaft

        CommandLineInterpreter oCLI = new CommandLineInterpreter();
        ActionCallingContext acc = new ActionCallingContext();

        acc.AddParameter("PropertyIdentName", "EPLAN.Project.UserSupplementaryField8");
        //acc.AddParameter("PropertyID", "10030"); für Standard Projekteigenschaften 
        acc.AddParameter("PropertyIndex", "0");
        acc.AddParameter("PropertyValue", totalWeight.ToString());

        oCLI.Execute("XEsSetProjectPropertyAction", acc);

        // Öffnen oder Löschen der temporären Dateien

        if (File.Exists(strBM_Gewichte))
        {
            DialogResult Result = MessageBox.Show("Die temporäre Datei anzeigen?", "Gewichte der Betriebsmittel", MessageBoxButtons.YesNo, MessageBoxIcon.Question);
            if (Result == DialogResult.Yes)
            {
                OpenFileDialog ofd = new OpenFileDialog();
                ofd.DefaultExt = "txt";
                ofd.FileName = strBM_Gewichte;
                ofd.InitialDirectory = PathMap.SubstitutePath("$(MD_DOCUMENTS)" + @"\Sammelordner P8\Gewichte\");
                ofd.Title = "temporäre Datei auswählen:";
                ofd.ValidateNames = true;

                if (ofd.ShowDialog() == DialogResult.OK)
                {
                }
            }
            else
            {
                File.Delete(strBM_Gewichte);
                MessageBox.Show("Die temporäre Datei der BM-Gewichte wurde gelöscht");
            }
        }

        if (File.Exists(strSchienen_Gewichte))
        {
            DialogResult Result = MessageBox.Show("Die temporäre Datei anzeigen?", "Gewichte der Schienen", MessageBoxButtons.YesNo, MessageBoxIcon.Question);
            if (Result == DialogResult.Yes)
            {
                OpenFileDialog ofd = new OpenFileDialog();
                ofd.DefaultExt = "txt";
                ofd.FileName = strSchienen_Gewichte;
                ofd.InitialDirectory = PathMap.SubstitutePath("$(MD_DOCUMENTS)" + @"\Sammelordner P8\Gewichte\");
                ofd.Title = "temporäre Datei auswählen:";
                ofd.ValidateNames = true;

                if (ofd.ShowDialog() == DialogResult.OK)
                {
                }
            }
            else
            {
                File.Delete(strSchienen_Gewichte);
                MessageBox.Show("Die temporäre Datei der Schienen-Gewichte wurde gelöscht");
            }


        }

        if (File.Exists(strLeitungen_Gewichte))
        {
            DialogResult Result = MessageBox.Show("Die temporäre Datei anzeigen?", "Gewichte der Schienen", MessageBoxButtons.YesNo, MessageBoxIcon.Question);
            if (Result == DialogResult.Yes)
            {
                OpenFileDialog ofd = new OpenFileDialog();
                ofd.DefaultExt = "txt";
                ofd.FileName = strLeitungen_Gewichte;
                ofd.InitialDirectory = PathMap.SubstitutePath("$(MD_DOCUMENTS)" + @"\Sammelordner P8\Gewichte\");
                ofd.Title = "temporäre Datei auswählen:";
                ofd.ValidateNames = true;

                if (ofd.ShowDialog() == DialogResult.OK)
                {
                }
            }
            else
            {
                File.Delete(strLeitungen_Gewichte);
                MessageBox.Show("Die temporäre Datei der Schienen-Gewichte wurde gelöscht");
            }

        }

    }
}
